*****************
Large Image Tasks
*****************

These are Girder Worker tasks used by Large Image.

This includes ``create_tiff`` to use vips to convert an image to a pyramidal tiff so it can be served efficiently from large_image.
